@@ -1,256 +1,144 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de" sourcelanguage="en">
-<context>
-    <name>DataModel</name>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Error</source>
-        <translation>Fehler</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Session conflicts with other sessions.</source>
-        <translation>Überschneidung mit anderem Eintrag.</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="256"/>
-        <location filename="../src/data_model.cpp" line="470"/>
-        <source>Total</source>
-        <translation>Summe</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="454"/>
-        <source>Date</source>
-        <translation>Datum</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="456"/>
-        <source>Start</source>
-        <translation>Start</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="458"/>
-        <source>Stop</source>
-        <translation>Ende</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="460"/>
-        <location filename="../src/window.cpp" line="138"/>
-        <source>Task</source>
-        <translation>Aufgabe</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="462"/>
-        <source>Hours</source>
-        <translation>Stunden</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="464"/>
-        <source>Daily</source>
-        <translation>Täglich</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="466"/>
-        <source>Weekly</source>
-        <translation>Wöchentlich</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="468"/>
-        <source>Monthly</source>
-        <translation>Monatlich</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="472"/>
-        <source>Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
+<TS version="2.1" language="de" sourcelanguage="en">
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="51"/>
         <source>Select application language:</source>
         <translation>Programmsprache auswählen</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="54"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Betriebssystemsprache&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Note</source>
         <translation>Achtung!</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Programm neu starten, um die Sprachänderung wirksam werden zu lassen.</translation>
     </message>
 </context>
-<context>
-    <name>Rates</name>
-    <message>
-        <location filename="../src/rates.cpp" line="36"/>
-        <source>$</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>Report</name>
     <message>
-        <location filename="../src/report.cpp" line="361"/>
         <source>Time Sheet Report</source>
         <translation>Zeiterfassungsbericht</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="70"/>
         <source>Name:</source>
         <translation>Name:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="71"/>
         <source>Company:</source>
         <translation>Firma:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="72"/>
         <source>Address:</source>
         <translation>Anschrift:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="73"/>
         <source>Phone:</source>
         <translation>Tel.:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="74"/>
         <source>Fax:</source>
         <translation>Fax:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="75"/>
         <source>Email:</source>
         <translation>E-Mail:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="76"/>
         <source>Website:</source>
         <translation>Website:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="104"/>
-        <location filename="../src/report.cpp" line="109"/>
         <source>N/A</source>
         <translation>N/A</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="113"/>
         <source>Prepend currency symbol</source>
         <translation>Währungssymbol voranstellen</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="120"/>
         <source>Hourly rate:</source>
         <translation>Stundensatz:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="121"/>
         <source>Tax rate:</source>
         <translation>MwSt.-Satz:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="122"/>
         <source>Currency symbol:</source>
         <translation>Währungssymbol:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="137"/>
         <source>Contact Information</source>
         <translation>Kontaktdaten</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="138"/>
         <source>Data</source>
         <translation>Zeiterfassungsdaten</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="139"/>
         <source>Preview</source>
         <translation>Vorschau</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="145"/>
         <source>Export</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportieren</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="146"/>
         <source>Print</source>
         <translation>Drucken</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="269"/>
         <source>Web Page (*.html *.htm)</source>
-        <translation type="unfinished"></translation>
+        <translation>Web Page (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="270"/>
         <source>iCalendar (*.ics)</source>
-        <translation type="unfinished"></translation>
+        <translation>iCalendar (*.ics)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="271"/>
         <source>Outlook CSV (*.csv)</source>
-        <translation type="unfinished"></translation>
+        <translation>Outlook CSV (*.csv)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="282"/>
         <source>Export Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Bericht exportieren</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="317"/>
         <source>View Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>Berichte anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="333"/>
         <source>Create Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Bericht erstellen</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="388"/>
         <source>Phone: %1</source>
         <translation>Tel.: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="392"/>
         <source>Fax: %1</source>
         <translation>Fax: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="448"/>
         <source>Hours</source>
         <translation>Stunden</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="455"/>
         <source>Subtotal</source>
         <translation>Zwischensumme</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="457"/>
         <source>Taxes</source>
         <translation>MwSt.</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="460"/>
         <source>Total</source>
         <translation>Endsumme</translation>
     </message>
@@ -258,7 +146,6 @@
 <context>
     <name>Session</name>
     <message numerus="yes">
-        <location filename="../src/session.cpp" line="50"/>
         <source>%n hour(s)</source>
         <translation>
             <numerusform>%n Stunde</numerusform>
@@ -266,314 +153,302 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/session.cpp" line="52"/>
         <source>%L1 hours</source>
         <translation>%L1 Stunden</translation>
     </message>
 </context>
+<context>
+    <name>SessionDelegate</name>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation>Überschneidung mit anderem Eintrag.</translation>
+    </message>
+</context>
 <context>
     <name>SessionDialog</name>
     <message>
-        <location filename="../src/session_dialog.cpp" line="33"/>
         <source>Add Session</source>
         <translation>Eintrag hinzufügen</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="54"/>
         <source>Date:</source>
         <translation>Datum:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="55"/>
         <source>Start:</source>
         <translation>Start:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="56"/>
         <source>Stop:</source>
         <translation>Ende:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="57"/>
         <source>Task:</source>
         <translation>Aufgabe:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="70"/>
         <source>Edit Session</source>
         <translation>Eintrag bearbeiten</translation>
     </message>
 </context>
 <context>
-    <name>Window</name>
+    <name>SessionModel</name>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
+        <source>Total</source>
+        <translation>Summe</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Datum</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Ende</translation>
+    </message>
+    <message>
+        <source>Task</source>
+        <translation>Aufgabe</translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation>Stunden</translation>
+    </message>
+    <message>
+        <source>Daily</source>
+        <translation>Täglich</translation>
+    </message>
+    <message>
+        <source>Weekly</source>
+        <translation>Wöchentlich</translation>
+    </message>
+    <message>
+        <source>Monthly</source>
+        <translation>Monatlich</translation>
+    </message>
+    <message>
+        <source>Report</source>
+        <translation>Bericht</translation>
+    </message>
+</context>
+<context>
+    <name>Window</name>
+    <message>
         <source>00:00:00</source>
         <translation>00:00:00</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="144"/>
         <source>Start</source>
         <translation>Start</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="149"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="155"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
+        <source>&amp;Minimize</source>
+        <translation>&amp;Minimieren</translation>
+    </message>
+    <message>
         <source>&amp;Project</source>
         <translation>&amp;Projekt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
-        <location filename="../src/window.cpp" line="184"/>
         <source>&amp;Add</source>
         <translation>&amp;Hinzufügen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
         <source>Ctrl+Shift+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Strg+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
-        <location filename="../src/window.cpp" line="187"/>
         <source>&amp;Remove</source>
         <translation>&amp;Entfernen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>Ctrl+Shift+Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Strg+Shift+Entf</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>&amp;Quit</source>
         <translation>&amp;Beenden</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="183"/>
         <source>&amp;Session</source>
         <translation>&amp;Eintrag</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="185"/>
         <source>&amp;Edit</source>
         <translation>&amp;Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="187"/>
         <source>Ctrl+Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Strg+Entf</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="190"/>
         <source>S&amp;ettings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="191"/>
         <source>Columns</source>
         <translation>Spalten</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="192"/>
         <source>&amp;Decimal Totals</source>
         <translation>&amp;Zeitanzeige dezimal</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="196"/>
         <source>&amp;Inline Editing</source>
         <translation>&amp;direkte Wertebearbeitung</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="201"/>
         <source>Application &amp;Language...</source>
         <translation>Programmsprache</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="203"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="204"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="205"/>
         <source>About &amp;Qt</source>
         <translation>Über &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Project</source>
         <translation>Projekt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Timer</source>
         <translation>Zeiterfassung</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="241"/>
         <source>Show all</source>
         <translation>Alle anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="242"/>
         <source>Show only unbilled</source>
         <translation>Nur nicht abgerechnete anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="243"/>
         <source>Show only this year</source>
         <translation>Nur dieses Jahr anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="244"/>
         <source>Show only this month</source>
         <translation>Nur diesen Monat anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="245"/>
         <source>Show only this week</source>
         <translation>Nur diese Woche anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="426"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright &amp;copy; 2008-2011 Graeme Gott.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="427"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
-        <translation type="unfinished"></translation>
+        <translation>Veröffentlicht unter &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation>Überschneidung mit anderem Eintrag.</translation>
+    </message>
+    <message>
+        <source>&amp;Restore</source>
+        <translation>&amp;Wiederherstellen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Unable to read time data.</source>
-        <translation type="unfinished"></translation>
+        <translation>Unfähig die Zeit zu lesen.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="593"/>
-        <location filename="../src/window.cpp" line="829"/>
-        <location filename="../src/window.cpp" line="925"/>
         <source>Untitled</source>
         <translation>Ohne Titel</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
         <source>Unable to write time data.</source>
-        <translation type="unfinished"></translation>
+        <translation>Unfähig die Zeit Daten zu schreiben. </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>There are timers running. Stop timers and quit?</source>
         <translation>Zeiterfassung läuft. Stoppen und Programm beenden?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="423"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="425"/>
         <source>A program to help track spent time</source>
         <translation>Ein Programm zur Zeiterfassung am Rechner.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
-        <location filename="../src/window.cpp" line="487"/>
-        <location filename="../src/window.cpp" line="559"/>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Question</source>
         <translation>Frage</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Create Report...</source>
-        <translation type="unfinished"></translation>
+        <translation>Bericht erstellen...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="178"/>
         <source>View R&amp;eports</source>
-        <translation type="unfinished"></translation>
+        <translation>Berichte anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>Cancel this session?</source>
         <translation>Eintrag abbrechen?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Add Project</source>
         <translation>Projekt hinzufügen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Enter project name:</source>
         <translation>Projektname eingeben:</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="124"/>
-        <location filename="../src/main.cpp" line="133"/>
-        <location filename="../src/window.cpp" line="542"/>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="133"/>
         <source>Unable to create time data location.</source>
-        <translation type="unfinished"></translation>
+        <translation>Der Zeitdaten Standort kann nicht erstellt werden.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="124"/>
         <source>Unable to move time data location.</source>
-        <translation type="unfinished"></translation>
+        <translation>Der Zeitdaten Speicherort kann nicht verschoben werden.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="542"/>
         <source>A project with that name already exists.</source>
         <translation>Ein Projekt dieses Namens besteht bereits.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="559"/>
         <source>Remove selected project?</source>
         <translation>Ausgewähltes Projekt löschen?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Remove selected session?</source>
         <translation>Ausgewählten Eintrag löschen?</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/window.cpp" line="1004"/>
         <source>%n timer(s) running</source>
         <translation>
             <numerusform>%n Zeiterfassung läuft</numerusform>
@@ -581,11 +456,31 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="424"/>
-        <location filename="../src/window.cpp" line="1001"/>
-        <location filename="../src/window.cpp" line="1011"/>
         <source>Kapow Punch Clock</source>
         <translation>Kapow Zeiterfassung</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Punch clock program</source>
+        <translation>Zeiterfassungsprogramm</translation>
+    </message>
+    <message>
+        <source>Store settings as INI format in specified file.</source>
+        <translation>Die Einstellungen als INI-Format in der angegebenen Datei speichern.</translation>
+    </message>
+    <message>
+        <source>file</source>
+        <translation>Datei</translation>
+    </message>
+    <message>
+        <source>Do not create automatic backups of time data.</source>
+        <translation>Keine automatischen Backups von Zeitdaten erstellen.</translation>
+    </message>
+    <message>
+        <source>The time data file to use.</source>
+        <translation>Die verwendete Zeitdatendatei.</translation>
+    </message>
+</context>
 </TS>
